==> ktoon_0.8.orig.tar.gz: ktoon-0.8/src/dlib/dgui/dtabwidget.h <==
/***************************************************************************
 *   Copyright (C) 2005 by David Cuadrado                                  *
 *   krawek@toonka.com                                          	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef DTABWIDGET_H
#define DTABWIDGET_H

#include <QTabWidget>

/**
 * @author David Cuadrado <krawek@toonka.com>
*/
class DTabWidget : public QTabWidget
{
	Q_OBJECT
	public:
		DTabWidget(QWidget *parent = 0);
		~DTabWidget();
		
	public slots:
		void removeAllTabs();
		
	protected:
#ifndef QT_NO_WHEELEVENT
    		virtual void wheelEvent( QWheelEvent *e );
#endif

	protected slots:
#ifndef QT_NO_WHEELEVENT
    		virtual void wheelMove( int delta );
#endif

};

#endif

==> ktoon_0.8.1.orig.tar.gz: ktoon-0.8.1/src/dlib/dgui/dtabwidget.h <==
/***************************************************************************
 *   Copyright (C) 2005 by David Cuadrado                                  *
 *   krawek@toonka.com                                          	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef DTABWIDGET_H
#define DTABWIDGET_H

#include <QTabWidget>

/**
 * @author David Cuadrado <krawek@toonka.com>
*/
class Q_GUI_EXPORT DTabWidget : public QTabWidget
{
	Q_OBJECT
	public:
		 DTabWidget(QWidget *parent = 0);
		~DTabWidget();
		
	public slots:
		void removeAllTabs();
		
	protected:
#ifndef QT_NO_WHEELEVENT
    		virtual void wheelEvent( QWheelEvent *e );
#endif

	protected slots:
#ifndef QT_NO_WHEELEVENT
    		virtual void wheelMove( int delta );
#endif

};

#endif
